clear


setpathdynare4;

load_results = 1;



paramfilename = 'rbcb_monprud_paramfile';

nperiods = 1000;  % set to 1 to start from the nonstochastic steady state
nreps = 1;

order = 2;
shocks_labels = char('errz');
s1 = RandStream('mt19937ar','seed',3);

nshocks = size(shocks_labels,1);
shock_mat = randn(s1,nreps,nshocks,nperiods);

if nperiods <3
    shock_mat = zeros(nreps,nshocks,nperiods);
end



if load_results
    load welfare_results_distorted
else
    
    eval(paramfilename)
    
    % Run model
    my_mpr_range =[0 0.5 1 2  3 4 ];  % this is for the spread bias
    my_cp_range = [0]; % this is for inflation bias
    
    tau2to1 = zeros(length(my_mpr_range),length(my_cp_range));
    
    
    spreadp = 0.005;
    save param_overwrite spreadp
    
    % NB: this model is out of the loop that, further down, will 
    % recompute the model solution
    dynare rbcb_monprud_nobias_ramsey_infl_bt  noclearall
    f1M_ = M_;
    f1oo_ = oo_;
    
    dynare rbcb_monprud_ramsey_infl_bt noclearall        
    f2M_ = M_;
    f2oo_ = oo_;
            
    dynare rbcb_monprud_nash_infl_bt noclearall
    f3M_ = M_;
    f3oo_ = oo_;
    
    
    % calculate vector for mapping the positions of the endogenous variables of model 2 into
    % those of model 1
    vec_2to1_pos = zeros(f1M_.endo_nbr,1);
    for this_var = 1:f2M_.endo_nbr
    % find a mapping from the declaration order of the first model to the
    % second model
        vec_2to1_pos(this_var) = strmatch(deblank(f1M_.endo_names(this_var,:)),f2M_.endo_names,'exact');
    end
    
    % calculate vector for mapping the positions of the endogenous variables of model 3 into
    % those of model 2
    
    % In this case, one has to deal with the lagrange multipliers for the Nash problem 
    % -- Remember to make sure that the
    % declaration of the objective functions in the original .mod file happens
    % at the end of the file, right before the declaration of the exogenous
    % block of equations
    
    vec_2to3_pos = zeros(f2M_.endo_nbr,1);
    for this_var = 1:f3M_.endo_nbr
        % find a mapping from the declaration order of the first model to the
        % second model
        varname = deblank(f3M_.endo_names(this_var,:));
        % deal with the fact that the Nash model has 2 Welfcorrection
        % variables -- both are mapped into the same Welfcorrection 
        % from teh Ramsey problem
        if regexp(varname,'Welfcorrection')
            varname = 'Welfcorrection';
        end
        
        
        if regexp(varname,'mult')
            % if mult is in the name of the variable, assume that variable is a
            % multiplier
            vec_2to3_pos(this_var) = strmatch(varname(3:end),f2M_.endo_names,'exact');
        else
            vec_2to3_pos(this_var) = strmatch(varname,f2M_.endo_names,'exact');
        end
    end

    
    % now lookp through the values chosen for the bias parameters
    my_mpr_index = 0;
    for my_mpr_loop = my_mpr_range
        my_mpr_index = my_mpr_index+1;
        my_cp_index = 0;
        for my_cp_loop = my_cp_range
            my_cp_index=my_cp_index+1;
            
            mu_mpr = my_mpr_loop;
            mu_cb = my_cp_loop;
            save param_overwrite mu_cb mu_mpr spreadp
                      
            % recompute the decision rules with updated parameters
            rbcb_monprud_ramsey_infl_bt 
            f2M_ = M_;
            f2oo_ = oo_;
            
            rbcb_monprud_nash_infl_bt       
            f3M_ = M_;
            f3oo_ = oo_;
            
            f1Welf = zeros(nreps,1);
            f2Welf = zeros(nreps,1);
            f3Welf = zeros(nreps,1);
            
            for this_rep = 1:nreps
                [this_rep mu_cb mu_mpr]
                
                % select the shock from the shock matrix
                this_shock = reshape(shock_mat(this_rep,:,:),nshocks,nperiods);
                
                % sample from the ergodic distribution of the second model
                % -- in this case biased cooperative ramsey
                [s2 penultimatepoint1 penultimatepoint2] = mymkdata2(f2M_,f2oo_,nperiods,order,shocks_labels,this_shock);
                f2Welf(this_rep) = s2.Welf_nobias_irf(end)+s2.Welf_nobias_ss;
               
                
                % ask how much would I pay to switch to unbiased policies
                s1 = mymkdata2(f1M_,f1oo_,1,order,shocks_labels,this_shock(:,end),penultimatepoint1(vec_2to1_pos),penultimatepoint2(vec_2to1_pos));
                f1Welf(this_rep) = s1.Welf_irf(end)+s1.Welf_ss;
                
                % ask how much I would have to get paid to switch to NASH
                % policies with a bias
                s3 = mymkdata2(f3M_,f3oo_,1,order,shocks_labels,this_shock(:,end),penultimatepoint1(vec_2to3_pos),penultimatepoint2(vec_2to3_pos));
                f3Welf(this_rep) = s3.Welf_nobias_irf(end)+s3.Welf_nobias_ss;
                
                
            end
            tau2to1(my_mpr_index,my_cp_index) = mean(exp((1-betap)*(f1Welf-f2Welf))-1);
            tau3to2(my_mpr_index,my_cp_index) = mean(exp((1-betap)*(f2Welf-f3Welf))-1);
            
        end
    end
    
    save welfare_results_distorted my_mpr_range tau2to1 tau3to2

end

figure

plot(my_mpr_range, 100*tau2to1(:,1),'b--','LineWidth',1.5); hold on
legend('Welfare cost of biased preferences with cooperation','Welfare cost of competition with biased preferences')
ylabel('Percent of consumption')
xlabel('Bias on Spread Stabilization, \omega_s')

plot(my_mpr_range, 100*tau3to2(:,1),'k','LineWidth',1.5); 
legend('Welfare cost of biased preferences with cooperation','Welfare cost of competition with biased preferences')



% figure
% 
% subplot(2,1,1)
% 
% spline_range = 0:0.02:my_mpr_range(end);
% spline_tau = spline(my_mpr_range,tau2to1(:,1),spline_range);
% plot(spline_range,spline_tau*100,'b-'); hold on
% 
% xlim([0 spline_range(end)])
% xlabel('Bias on Spread Stabilization, \omega_s')
% ylabel('Percent of Consumption')
% title('Welfare Cost of Stabilization Biases with Cooperative Policies')
% 
% subplot(2,1,2)
% spline_range = 0:0.02:my_mpr_range(end)
% spline_tau = spline(my_mpr_range,tau3to2(:,1),spline_range);
% plot(spline_range,spline_tau*100,'b-'); hold on
% 
% 
% xlim([0 spline_range(end)])
% xlabel('Bias on Spread Stabilization, \omega_s')
% ylabel('Percent of Consumption')
% title('Welfare Cost of Stabilization Biases with Open-loop Nash Policies')
% 
% legend('No Bias on Infl. Stabilization \omega_i = 0','Bias on Infl. Stabilization \omega_i = 1','location','NorthWest')
% printpref